@@ -113,11 +113,8 @@ m_menubar2 = new wxMenuBar( 0 );
 	m_choice6->SetSelection( 0 );
 	fgSizer31->Add( m_choice6, 0, wxALL, 5 );
 
-
 	fgSizer31->Add( 15, 0, 1, wxEXPAND, 5 );
-
 	sbSizer31->Add( fgSizer31, 0, wxEXPAND, 5 );
-
 	bSizer3->Add( sbSizer31, 0, wxEXPAND|wxRIGHT|wxLEFT, 5 );
 
 	////////////////////////////////FINE DATA//////////////////////////////////////////////////////////////
@@ -130,10 +127,7 @@ m_menubar2 = new wxMenuBar( 0 );
 	fgSizer3->SetFlexibleDirection( wxBOTH );
 	fgSizer3->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
 
-
 	fgSizer3->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
 	fgSizer3->Add( 0, 10, 1, wxEXPAND, 5 );
 
 	m_staticText105 = new wxStaticText( this, wxID_ANY, wxT("   Deg°"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -148,13 +142,8 @@ m_menubar2 = new wxMenuBar( 0 );
 	m_staticText107->Wrap( -1 );
 	fgSizer3->Add( m_staticText107, 0, wxALL, 5 );
 
-
 	fgSizer3->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
 	fgSizer3->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
 	fgSizer3->Add( 0, 10, 1, wxEXPAND, 5 );
 
 	m_staticText1051 = new wxStaticText( this, wxID_ANY, wxT("   Deg°"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -169,7 +158,6 @@ m_menubar2 = new wxMenuBar( 0 );
 	m_staticText1071->Wrap( -1 );
 	fgSizer3->Add( m_staticText1071, 0, wxALL, 5 );
 
-
 	fgSizer3->Add( 0, 0, 1, wxEXPAND, 5 );
 
 	m_staticText109 = new wxStaticText( this, wxID_ANY, wxT("Latitude:"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -195,7 +183,6 @@ m_menubar2 = new wxMenuBar( 0 );
 	m_textCtrl1->SetMaxLength( 2 );
 	fgSizer3->Add( m_textCtrl1, 0, wxRIGHT|wxLEFT, 5 );
 
-
 	fgSizer3->Add( 0, 0, 1, wxEXPAND, 5 );
 
 	m_staticText111 = new wxStaticText( this, 14, wxT("Longitude:"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -233,7 +220,6 @@ m_menubar2 = new wxMenuBar( 0 );
 	fgSizer2->SetFlexibleDirection( wxBOTH );
 	fgSizer2->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
 
-
 	fgSizer2->Add( 0, 10, 1, wxEXPAND, 5 );
 
 	m_staticText151 = new wxStaticText( this, wxID_ANY, wxT("Hours"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -251,11 +237,7 @@ m_menubar2 = new wxMenuBar( 0 );
 	m_button7 = new wxButton( this, 18, wxT("Start"), wxDefaultPosition, wxSize( 50,25 ), 0 );
 	fgSizer2->Add( m_button7, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
 
-
-
 	fgSizer2->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
 	//fgSizer2->Add( 0, 0, 1, wxEXPAND, 5 );
 
 	m_staticText15 = new wxStaticText( this, wxID_ANY, wxT("Hours"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -274,8 +256,6 @@ m_menubar2 = new wxMenuBar( 0 );
 	fgSizer2->Add( m_button6, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
 
 	fgSizer2->Add( 0, 0, 1, wxEXPAND, 5 );
-
-
 	fgSizer2->Add( 0, 0, 1, wxEXPAND, 5 );
 
 	m_staticText8 = new wxStaticText( this, wxID_ANY, wxT("Time UTC:"), wxDefaultPosition, wxDefaultSize, 0 );
@@ -297,12 +277,9 @@ m_menubar2 = new wxMenuBar( 0 );
 	m_button8 = new wxButton( this, 22, wxT("Stop"), wxDefaultPosition, wxSize( 50,25 ), 0 );
 	fgSizer2->Add( m_button8, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
 
-
 	m_staticText21 = new wxStaticText( this, wxID_ANY, wxT("Local time:"), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText21->Wrap( -1 );
 	fgSizer2->Add( m_staticText21, 0, wxALL, 5 );
-
-
 	//fgSizer2->Add( 0, 0, 1, wxEXPAND, 5 );
 
 	m_textCtrl1111 = new wxTextCtrl( this, 23, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ),wxTE_RIGHT );
@@ -315,7 +292,7 @@ m_menubar2 = new wxMenuBar( 0 );
 
 	m_textCtrl1113 = new wxTextCtrl( this, 25, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ),wxTE_RIGHT );
 	m_textCtrl1113->SetMaxLength( 2 );
-	
+
 	fgSizer2->Add( m_textCtrl1113, 0, wxBOTTOM|wxRIGHT, 5 );
 
 	m_button9 = new wxButton( this, 27, wxT("Local "), wxDefaultPosition, wxSize( 50,25 ), 0 );
@@ -328,32 +305,28 @@ m_menubar2 = new wxMenuBar( 0 );
 	wxStaticBoxSizer* sbSizer5;
 	sbSizer5 = new wxStaticBoxSizer( new wxStaticBox( this, wxID_ANY, wxT("Observation:") ), wxVERTICAL );
 
-	wxFlexGridSizer* fgSizer5;
-	fgSizer5 = new wxFlexGridSizer( 3, 6, 0, 0 );
-	fgSizer5->SetFlexibleDirection( wxBOTH );
-	//fgSizer5->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	////////////////////////////////////////////new 7 apr 2012/////////////////////////////////////////////////////////////
+	wxGridBagSizer* gbSizer3;
+	gbSizer3 = new wxGridBagSizer( 0, 0 );
+	gbSizer3->SetFlexibleDirection( wxBOTH );
+	gbSizer3->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
 
+	gbSizer3->SetMinSize( wxSize( 100,10 ) );
 
-	fgSizer5->Add( 0, 10, 1, wxEXPAND, 5 );
+	gbSizer3->Add( 100, 10, wxGBPosition( 0, 0 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
+	sbSizer5->Add( gbSizer3, 0, wxEXPAND, 5 );
 
-	fgSizer5->Add( 0, 10, 1, wxEXPAND, 5 );
+	wxGridBagSizer* gbSizer4;
+	gbSizer4 = new wxGridBagSizer( 0, 0 );
+	gbSizer4->SetFlexibleDirection( wxBOTH );
+	gbSizer4->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
 
+	gbSizer4->SetMinSize( wxSize( 100,30 ) );
 
-	fgSizer5->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
-	fgSizer5->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
-	fgSizer5->Add( 0, 10, 1, wxEXPAND, 5 );
-
-
-	fgSizer5->Add( 0, 10, 1, wxEXPAND, 5 );
-
-	m_staticText24 = new wxStaticText( this, wxID_ANY, wxT("Star name:"), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText24 = new wxStaticText( this, wxID_ANY, wxT("Star name:       "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText24->Wrap( -1 );
-	fgSizer5->Add( m_staticText24, 0, wxALL, 5 );
+	gbSizer4->Add( m_staticText24, wxGBPosition( 0, 0 ), wxGBSpan( 1, 1 ), wxALIGN_CENTER, 5 );
 
 	m_comboBox3 = new wxComboBox( this, 28, wxEmptyString, wxDefaultPosition, wxSize( 120,25 ), 0, NULL,  wxCB_READONLY );
 	m_comboBox3->Append( wxT("Acamar") );
@@ -422,197 +395,268 @@ m_menubar2 = new wxMenuBar( 0 );
 		m_comboBox3->Append( wxT("Suhail") );
 		m_comboBox3->Append( wxT("Vega") );
 		m_comboBox3->Append( wxT("Zuben el Genubi") );
+	gbSizer4->Add( m_comboBox3, wxGBPosition( 0, 1 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxTOP, 5 );
 
-	fgSizer5->Add( m_comboBox3, 0, wxBOTTOM, 5 );
-
-
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	gbSizer4->Add( 142, 10, wxGBPosition( 0, 2 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
 	m_button1 = new wxButton( this, 29, wxT("Calc Altitude"), wxDefaultPosition, wxSize( 100,25 ), 0 );
-	fgSizer5->Add( m_button1, 0, wxRIGHT|wxLEFT, 5 );
+	gbSizer4->Add( m_button1, wxGBPosition( 0, 3 ), wxGBSpan( 1, 1 ), wxALL, 5 );
 
 	m_button11 = new wxButton( this, 30, wxT("info"), wxDefaultPosition, wxSize( 100,25 ), 0 );
-	fgSizer5->Add( m_button11, 0, wxRIGHT|wxLEFT, 5 );
+	gbSizer4->Add( m_button11, wxGBPosition( 0, 4 ), wxGBSpan( 1, 1 ), wxALL, 5 );
 
-	
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	sbSizer5->Add( gbSizer4, 0, wxEXPAND, 5 );
 
-	m_staticText25 = new wxStaticText( this, wxID_ANY, wxT("Solar System:"), wxDefaultPosition, wxDefaultSize, 0 );
+	wxGridBagSizer* gbSizer5;
+	gbSizer5 = new wxGridBagSizer( 0, 0 );
+	gbSizer5->SetFlexibleDirection( wxBOTH );
+	gbSizer5->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer5->SetMinSize( wxSize( 100,10 ) );
+
+	sbSizer5->Add( gbSizer5, 0, wxEXPAND, 5 );
+
+	m_staticText25 = new wxStaticText( this, wxID_ANY, wxT("Solar System:  "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText25->Wrap( -1 );
-	fgSizer5->Add( m_staticText25, 0, wxALL, 5 );
+	gbSizer5->Add( m_staticText25, wxGBPosition( 0, 0 ), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
 	m_comboBox31 = new wxComboBox( this, 31, wxEmptyString, wxDefaultPosition, wxSize( 120,25 ), 0, NULL,  wxCB_READONLY);
-
 	m_comboBox31->Append( wxT("Sun") );
 	m_comboBox31->Append( wxT("Moon") );
 	m_comboBox31->Append( wxT("Venus") );
 	m_comboBox31->Append( wxT("Mars") );
 	m_comboBox31->Append( wxT("Jupiter") );
 	m_comboBox31->Append( wxT("Saturn") );
-	fgSizer5->Add( m_comboBox31, 0, wxRIGHT, 5 );
+	gbSizer5->Add( m_comboBox31, wxGBPosition( 0, 1 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxBOTTOM, 5 );
 
-	m_staticText29 = new wxStaticText( this, wxID_ANY, wxT("Observed Altitude:"), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText29 = new wxStaticText( this, wxID_ANY, wxT("    Observed Altitude:   "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText29->Wrap( -1 );
-	fgSizer5->Add( m_staticText29, 0, wxTOP|wxBOTTOM, 5 );
+	gbSizer5->Add( m_staticText29, wxGBPosition( 0, 2 ), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
-	m_textCtrl241 = new wxTextCtrl( this, 35, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ), wxTE_RIGHT );
+	m_textCtrl241 = new wxTextCtrl( this, 35, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ), wxALIGN_RIGHT );
 	m_textCtrl241->SetMaxLength( 2 );//obs altitude degrees
+	gbSizer5->Add( m_textCtrl241, wxGBPosition( 0, 3 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	fgSizer5->Add( m_textCtrl241, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	gbSizer5->Add( 4, 10, wxGBPosition( 0, 4 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	m_textCtrl244 = new wxTextCtrl( this, 36, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ),wxALIGN_LEFT );
+	m_textCtrl244->SetMaxLength( 3 );// altitude minutes
+	gbSizer5->Add( m_textCtrl244, wxGBPosition( 0, 5 ), wxGBSpan( 1, 1 ),wxALIGN_RIGHT|wxCENTER, 5 );
 
+	gbSizer5->Add( 4, 10, wxGBPosition( 0, 6 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	m_textCtrl243 = new wxTextCtrl( this, 37, wxEmptyString,  wxDefaultPosition, wxSize( 50,25 ),wxTE_RIGHT );
+	m_textCtrl243->SetMaxLength( 2 );// altitude seconds
+	gbSizer5->Add( m_textCtrl243, wxGBPosition( 0, 7 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	m_staticText28 = new wxStaticText( this, wxID_ANY, wxT("Calculated Alt:"), wxDefaultPosition, wxDefaultSize, 0 );
+	gbSizer5->Add( 4, 10, wxGBPosition( 0, 8 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
+
+	m_checkBox1 = new wxCheckBox( this, 38, wxT("upper limb"),  wxDefaultPosition, wxDefaultSize, 0 );
+	gbSizer5->Add( m_checkBox1, wxGBPosition( 0, 9 ), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxBOTTOM, 5 );
+	//upper limb*/
+/////////////////////////altra linea////////////////////////////
+	wxGridBagSizer* gbSizer6;
+	gbSizer6 = new wxGridBagSizer( 0, 0 );
+	gbSizer6->SetFlexibleDirection( wxBOTH );
+	gbSizer6->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer6->SetMinSize( wxSize( 100,10 ) );
+
+	m_staticText28 = new wxStaticText( this, wxID_ANY, wxT("Calculated Alt: "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText28->Wrap( -1 );
-	fgSizer5->Add( m_staticText28, 0, wxALL, 5 );
+	gbSizer6->Add( m_staticText28, wxGBPosition( 0, 0 ), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
 	m_textCtrl24 = new wxTextCtrl( this, 32, wxEmptyString, wxDefaultPosition, wxSize( 100,25 ), wxTE_READONLY|wxTE_RIGHT );
-	fgSizer5->Add( m_textCtrl24, 0, wxRIGHT, 5 );//altitude
+	gbSizer6->Add( m_textCtrl24, wxGBPosition( 0, 1 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );//altitude
 
-	m_staticText301 = new wxStaticText( this, wxID_ANY, wxT("            Index error:"), wxDefaultPosition, wxDefaultSize, 0 );
+	gbSizer6->Add( 85, 10, wxGBPosition( 0, 2 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
+
+	m_staticText301 = new wxStaticText( this, wxID_ANY, wxT("Index error:  "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText301->Wrap( -1 );
-	fgSizer5->Add( m_staticText301, 0, wxTOP, 5 );
+	gbSizer6->Add( m_staticText301, wxGBPosition( 0, 3), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
 	m_textCtrl2421 = new wxTextCtrl( this, 39, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ), wxTE_RIGHT );
 	m_textCtrl2421->SetMaxLength( 4 );//index error
+	gbSizer6->Add( m_textCtrl2421, wxGBPosition( 0, 4 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	fgSizer5->Add( m_textCtrl2421, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	gbSizer6->Add( 30, 10, wxGBPosition( 0, 5 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
-
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
-
-	////////////////////////////////////////////////////addings///////////////////////////////////////////////////
-	m_textCtrl244 = new wxTextCtrl( this, 36, wxEmptyString, wxPoint(423,320), wxSize( 50,25 ),wxTE_RIGHT );
-	m_textCtrl244->SetMaxLength( 3 );// altitude minutes
-
-	m_textCtrl243 = new wxTextCtrl( this, 37, wxEmptyString, wxPoint(476,320), wxSize( 50,25 ),wxTE_RIGHT );
-	m_textCtrl243->SetMaxLength( 2 );// altitude seconds
-	
-	m_checkBox1 = new wxCheckBox( this, 38, wxT("upper limb"), wxPoint(535,315), wxDefaultSize, 0 );
-	//upper limb
-
-
-	m_staticText10 = new wxStaticText( this, wxID_ANY, wxT("Eye height:"), wxPoint(445,354), wxDefaultSize, 0 );
+	m_staticText10 = new wxStaticText( this, wxID_ANY, wxT("Eye height:  "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText10->Wrap( -1 );
+	gbSizer6->Add( m_staticText10, wxGBPosition( 0, 6), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
-	m_textCtrl245 = new wxTextCtrl( this, 40, wxEmptyString, wxPoint(529,350), wxSize( 50,25 ),wxTE_RIGHT );
+	m_textCtrl245 = new wxTextCtrl( this, 40, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ),wxTE_RIGHT );
 	m_textCtrl245->SetMaxLength( 4 );//eye height
-	
-	m_staticText7 = new wxStaticText( this, wxID_ANY, wxT("mt"), wxPoint(583,358), wxDefaultSize, 0 );
+	gbSizer6->Add( m_textCtrl245, wxGBPosition( 0, 7 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
+
+	m_staticText7 = new wxStaticText( this, wxID_ANY, wxT("  mt."), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText7->Wrap( -1 );
+	gbSizer6->Add( m_staticText7, wxGBPosition( 0, 8), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
-	m_textCtrl246 = new wxTextCtrl( this, 41, wxEmptyString, wxPoint(370,380), wxSize( 50,25 ),wxTE_READONLY|wxTE_RIGHT );
-	m_textCtrl246->SetMaxLength( 4 );//intercept
+	sbSizer5->Add( gbSizer6, 0, wxEXPAND, 5 );
+///////////////altra linea//////////////////////////////
+	wxGridBagSizer* gbSizer7;
+	gbSizer7 = new wxGridBagSizer( 0, 0 );
+	gbSizer7->SetFlexibleDirection( wxBOTH );
+	gbSizer7->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer7->SetMinSize( wxSize( 100,0 ) );
 
+	gbSizer7->Add( 30, 4, wxGBPosition( 0, 5 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-	m_staticText9 = new wxStaticText( this, wxID_ANY, wxT("Intercept:"), wxPoint(302,385), wxDefaultSize, 0 );
-	m_staticText9->Wrap( -1 );
-	//true altitude
-	m_textCtrl247 = new wxTextCtrl( this, 42, wxEmptyString, wxPoint(370,410), wxSize( 100,25 ),wxTE_READONLY|wxTE_RIGHT );
+	sbSizer5->Add( gbSizer7, 0, wxEXPAND, 5 );
+/////////altra linea/////////////////////////////////////
+	wxGridBagSizer* gbSizer8;
+	gbSizer8 = new wxGridBagSizer( 0, 0 );
+	gbSizer8->SetFlexibleDirection( wxBOTH );
+	gbSizer8->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer8->SetMinSize( wxSize( 100,10 ) );
 
-
-	m_staticText10 = new wxStaticText( this, wxID_ANY, wxT("Miles"), wxPoint(425,388), wxDefaultSize, 0 );
-	m_staticText10->Wrap( -1 );
-
-	m_staticText8 = new wxStaticText( this, wxID_ANY, wxT("True Altitude:"), wxPoint(277,414), wxDefaultSize, 0 );
-	m_staticText8->Wrap( -1 );
-
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-	
-
-	m_staticText30 = new wxStaticText( this, wxID_ANY, wxT("Azimuth:"), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText30 = new wxStaticText( this, wxID_ANY, wxT("Azimuth:          "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText30->Wrap( -1 );
-	fgSizer5->Add( m_staticText30, 0, wxALL, 5 );
+	gbSizer8->Add( m_staticText30, wxGBPosition( 0, 0), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
 	m_textCtrl242 = new wxTextCtrl( this, 33, wxEmptyString, wxDefaultPosition, wxSize( 100,25 ), wxTE_RIGHT );
-	fgSizer5->Add( m_textCtrl242, 0, wxBOTTOM|wxRIGHT, 5 );//azimuth
+	gbSizer8->Add( m_textCtrl242, wxGBPosition( 0, 1 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );//azimuth
 
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	gbSizer8->Add( 99, 4, wxGBPosition( 0, 2 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
+	m_staticText9 = new wxStaticText( this, wxID_ANY, wxT("Intercept:  "), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText9->Wrap( -1 );
+	gbSizer8->Add( m_staticText9, wxGBPosition( 0, 3), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	m_textCtrl246 = new wxTextCtrl( this, 41, wxEmptyString, wxDefaultPosition, wxSize( 50,25 ),wxTE_READONLY|wxTE_RIGHT );
+	m_textCtrl246->SetMaxLength( 4 );//intercept
+	gbSizer8->Add( m_textCtrl246, wxGBPosition( 0, 4 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	m_staticText10 = new wxStaticText( this, wxID_ANY, wxT("  Miles"), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText10->Wrap( -1 );
+	gbSizer8->Add( m_staticText10, wxGBPosition( 0, 5), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
+	sbSizer5->Add( gbSizer8, 0, wxEXPAND, 5 );
+////////////////////////////////altra linea/////////////////////////////////////////////
+	wxGridBagSizer* gbSizer9;
+	gbSizer9 = new wxGridBagSizer( 0, 0 );
+	gbSizer9->SetFlexibleDirection( wxBOTH );
+	gbSizer9->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer9->SetMinSize( wxSize( 100,0 ) );
 
-	fgSizer5->Add( 0, 0, 1, wxEXPAND, 5 );
+	gbSizer9->Add( 30, 4, wxGBPosition( 0, 5 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-	m_staticText211 = new wxStaticText( this, wxID_ANY, wxT("Star unknown:"), wxDefaultPosition, wxDefaultSize, wxTE_RIGHT );
+	sbSizer5->Add( gbSizer9, 0, wxEXPAND, 5 );
+
+//////////////////////////////////////altra linea/////////////////////////////////////////
+	wxGridBagSizer* gbSizer10;
+	gbSizer10 = new wxGridBagSizer( 0, 0 );
+	gbSizer10->SetFlexibleDirection( wxBOTH );
+	gbSizer10->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer10->SetMinSize( wxSize( 100,10 ) );
+
+	m_staticText211 = new wxStaticText( this, wxID_ANY, wxT("Star unknown: "), wxDefaultPosition, wxDefaultSize, wxTE_RIGHT );
 	m_staticText211->Wrap( -1 );
-	fgSizer5->Add( m_staticText211, 0, wxALL, 5 );
+	gbSizer10->Add( m_staticText211, wxGBPosition( 0, 0), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
 	m_textCtrl24211 = new wxTextCtrl( this,34, wxT("No match"), wxDefaultPosition, wxSize( 100,25 ),wxTE_READONLY|wxTE_RIGHT );
-	fgSizer5->Add( m_textCtrl24211, 0, wxBOTTOM|wxRIGHT, 5 );//unknown star
+	gbSizer10->Add( m_textCtrl24211, wxGBPosition( 0, 1 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );//unknown star
 
+	gbSizer10->Add( 75, 4, wxGBPosition( 0, 2 ), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-	fgSizer5->Add( 10, 0, 1, wxEXPAND, 5 );
-	fgSizer5->Add( 10, 0, 1, wxEXPAND, 5 );
+	m_staticText8 = new wxStaticText( this, wxID_ANY, wxT("True Altitude:  "), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText8->Wrap( -1 );
+	gbSizer10->Add( m_staticText8, wxGBPosition( 0, 3), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
+
+	//true altitude
+	m_textCtrl247 = new wxTextCtrl( this, 42, wxEmptyString, wxDefaultPosition, wxSize( 100,25 ),wxTE_READONLY|wxTE_RIGHT );
+	gbSizer10->Add( m_textCtrl247, wxGBPosition( 0, 4 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
+
+	gbSizer10->Add( 15, 4, wxGBPosition( 0, 5), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
 	m_button4 = new wxButton( this, 43, wxT("Save"), wxDefaultPosition, wxSize( 100,25 ), 0 );
+	gbSizer10->Add( m_button4, wxGBPosition( 0, 6), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	fgSizer5->Add( m_button4, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	sbSizer5->Add( gbSizer10, 0, wxEXPAND, 5 );
 
-	sbSizer5->Add( fgSizer5, 0, wxEXPAND, 5 );
 
 	bSizer3->Add( sbSizer5, 0, wxALL|wxEXPAND, 5 );
 
 /////////////////////////////////////POSIZIONE///////////////////////////////////////////////
-wxStaticBoxSizer* sbSizer7;
-	sbSizer7 = new wxStaticBoxSizer( new wxStaticBox( this, wxID_ANY, wxT("Position:") ), wxHORIZONTAL );
+	wxStaticBoxSizer* sbSizer7;
+	sbSizer7 = new wxStaticBoxSizer( new wxStaticBox( this, wxID_ANY, wxT("Position:") ), wxVERTICAL );
+//////////////////prima linea///////////////////////////
+	wxGridBagSizer* gbSizer11;
+	gbSizer11 = new wxGridBagSizer( 0, 0 );
+	gbSizer11->SetFlexibleDirection( wxBOTH );
+	gbSizer11->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer11->SetMinSize( wxSize( 10,10 ) );
 
-	wxFlexGridSizer* fgSizer7;
-	fgSizer7 = new wxFlexGridSizer( 3, 12, 0, 0 );
-	fgSizer7->SetFlexibleDirection( wxBOTH );
-	fgSizer7->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer11->Add( 50, 10, wxGBPosition( 0,1), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-	
+	sbSizer7->Add( gbSizer11, 0, wxEXPAND, 5 );
+//////////////////////////////////////////////seconda linea///////////////////////////////////////////////
+	wxGridBagSizer* gbSizer12;
+	gbSizer12 = new wxGridBagSizer( 0, 0 );
+	gbSizer12->SetFlexibleDirection( wxBOTH );
+	gbSizer12->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer12->SetMinSize( wxSize( 0,0 ) );
 
-	m_button41 = new wxButton( this, 44, wxT("Cancel Saved"), wxDefaultPosition, wxSize( 100,25 ), 0 );
-	fgSizer7->Add( m_button41, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
-
-		fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-
-	m_button40 = new wxButton( this, 45, wxT("Meridian"), wxDefaultPosition, wxSize( 100,25 ), 0 );
-	fgSizer7->Add( m_button40, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
-
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
 
 	m_button411 = new wxButton( this, 46, wxT("Calc Position"), wxDefaultPosition, wxSize( 100,25 ), 0 );
-	fgSizer7->Add( m_button411, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	gbSizer12->Add( m_button411, wxGBPosition( 0, 0), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
+	gbSizer12->Add( 50, 10, wxGBPosition( 0,1), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
-
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 30, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 100, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-	fgSizer7->Add( 0, 0, 1, wxEXPAND, 5 );
-
-
-
-	m_staticText1091 = new wxStaticText( this, wxID_ANY, wxT("   Latitude : "), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText1091 = new wxStaticText( this, wxID_ANY, wxT("Latitude : "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText1091->Wrap( -1 );
-	fgSizer7->Add( m_staticText1091, 0, wxALL, 5 );
+	gbSizer12->Add( m_staticText1091, wxGBPosition( 0, 2), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
 
 	m_textCtrl2422 = new wxTextCtrl( this, 47, wxEmptyString, wxDefaultPosition, wxSize( 100,25 ), wxTE_RIGHT );
-	fgSizer7->Add( m_textCtrl2422, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	gbSizer12->Add( m_textCtrl2422, wxGBPosition( 0, 3 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	m_staticText1111 = new wxStaticText( this, wxID_ANY, wxT("       Longitude:"), wxDefaultPosition, wxDefaultSize, 0 );
+	gbSizer12->Add( 50, 2, wxGBPosition( 0,4), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
+
+	m_staticText1111 = new wxStaticText( this, wxID_ANY, wxT("Longitude: "), wxDefaultPosition, wxDefaultSize, 0 );
 	m_staticText1111->Wrap( -1 );
-	fgSizer7->Add( m_staticText1111, 0, wxALL, 5 );
+	gbSizer12->Add( m_staticText1111, wxGBPosition( 0, 5), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
+
+	gbSizer12->Add( 5, 10, wxGBPosition( 0,6), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
 
 	m_textCtrl24221 = new wxTextCtrl( this, 48, wxEmptyString, wxDefaultPosition, wxSize( 100,25 ), wxTE_RIGHT );
-	fgSizer7->Add( m_textCtrl24221, 0, wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	gbSizer12->Add( m_textCtrl24221, wxGBPosition( 0, 7 ), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
 
-	sbSizer7->Add( fgSizer7, 0, wxEXPAND, 5 );
+
+	sbSizer7->Add( gbSizer12, 0, wxEXPAND, 5 );
+//////////////////////////////////////////TERZA LINEA/////////////////////////////////////
+	wxGridBagSizer* gbSizer13;
+	gbSizer13 = new wxGridBagSizer( 0, 0 );
+	gbSizer13->SetFlexibleDirection( wxBOTH );
+	gbSizer13->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer13->SetMinSize( wxSize( 0,0 ) );
+
+	m_button40 = new wxButton( this, 45, wxT("Meridian"), wxDefaultPosition, wxSize( 100,25 ), 0 );
+	gbSizer13->Add( m_button40, wxGBPosition( 0, 0), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
+	///////////////14 apr 2012 aggiunte, da togliere a fine lavori///////////////////////
+	gbSizer13->Add( 50, 2, wxGBPosition( 0,1), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
+
+	m_staticText22 = new wxStaticText( this, wxID_ANY, wxT("Stars above the horizon at current position : "), wxDefaultPosition, wxDefaultSize, 0 );
+	m_staticText22->Wrap( -1 );
+	gbSizer13->Add( m_staticText22, wxGBPosition( 0, 2), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxTOP, 5 );
+
+	gbSizer13->Add( 4, 10, wxGBPosition( 0,3), wxGBSpan( 1, 1 ), wxEXPAND, 5 );
+	//////////////added april 7///////////////////////////////////////////////////////
+	m_button43 = new wxButton( this, 46, wxT("Sky view"), wxDefaultPosition, wxSize( 100,25 ), 0 );
+	gbSizer13->Add( m_button43, wxGBPosition( 0, 4), wxGBSpan( 1, 1 ), wxALIGN_LEFT|wxCENTER, 5 );
+	
+//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+	sbSizer7->Add( gbSizer13, 0, wxEXPAND, 5 );
+/////////////////////////////////////QUARTA LINEA/////////////////////////////////
+	wxGridBagSizer* gbSizer14;
+	gbSizer14 = new wxGridBagSizer( 0, 0 );
+	gbSizer14->SetFlexibleDirection( wxBOTH );
+	gbSizer14->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
+	gbSizer14->SetMinSize( wxSize( 100,10 ) );
+
+	m_button41 = new wxButton( this, 44, wxT("Cancel Saved"), wxDefaultPosition, wxSize( 100,25 ), 0 );
+	gbSizer14->Add( m_button41, wxGBPosition( 0, 0), wxGBSpan( 1, 1 ), wxALIGN_RIGHT|wxCENTER, 5 );
+
+	sbSizer7->Add( gbSizer14, 0, wxEXPAND, 5 );
 
 	bSizer3->Add( sbSizer7, 0, wxEXPAND|wxALL, 5 );
 
@@ -678,6 +722,7 @@ wxStaticBoxSizer* sbSizer7;
 	m_button411->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnCalcPos ), NULL, this );
 	m_button41->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnCancLines ), NULL, this );
 	m_button40->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnMeridian ), NULL, this );
+	m_button43->Connect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnPlot ), NULL, this );
 	///////////////menu///////////
 	this->Connect( m_menuItem11->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( MainDialogBase::OnMenuSave ) );
 	this->Connect( m_menuItem12->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( MainDialogBase::OnMenuCancel ) );
@@ -745,6 +790,7 @@ MainDialogBase::~MainDialogBase()
 	m_button411->Disconnect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnCalcPos ), NULL, this );
 	m_button41->Disconnect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnCancLines ), NULL, this );
 	m_button40->Disconnect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnMeridian), NULL, this );
+	m_button43->Disconnect( wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler( MainDialogBase::OnPlot), NULL, this );
 	///menu
 	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( MainDialogBase::OnMenuSave ) );
 	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( MainDialogBase::OnMenuCancel ) );
