@@ -19,6 +19,7 @@
     along with Nautic.  If not, see <http://www.gnu.org/licenses/>.
 
  */
+
 #include "main.h"
 
 #define TIMER_ID 1000
@@ -655,7 +656,7 @@ void MainDialog::OnEyeHt( wxFocusEvent& event )
 
 		
 
-	int deg, mn, sc;
+	int deg;// mn, sc;
 	deg = floor(dTrueAlt);
 	double res = (dTrueAlt - deg) * 60;
 
@@ -830,6 +831,7 @@ void MainDialog::OnPlanetChoice()
 	loctime = t + longitude;
 	date = wxString::Format(_("%2.0f - %2.0f - %2.0f"),iDay,iMonth,iYear);
 	jul = wxString::Format(_("%lf"),mysun.jd);
+
 	if(iChoice==0)
 	{
 		bSun = true;
@@ -900,7 +902,7 @@ void MainDialog::OnPlanetChoice()
 
 		bPlanet = true;
 		planet.objnum = 2;
-	e = planet.mainPlanet(iYear,iMonth,iDay,iHour,iMinute,iSeconds);
+		e = planet.mainPlanet(iYear,iMonth,iDay,iHour,iMinute,iSeconds);
 		Ts = mysun.Ts;
 		RA = planet.RA;
 		Tm = Ts + planet.RA;
@@ -960,9 +962,8 @@ void MainDialog::OnPlanetChoice()
 
 		return;
 		}
-
-	
 }
+
 void MainDialog::OnCalcHeitht( wxCommandEvent& event )
 {
 	CalcAltitude();
@@ -1009,8 +1010,8 @@ void MainDialog::CalcAltitude()
 
 void MainDialog::OnTextEnter( wxFocusEvent& event ) //index error
 {
-	char s[4];
-	char * res, * st;
+	//char s[4];
+	//char * res, * st;
 	double val,rest;
 	val = 0;
 	rest = 0;
@@ -1045,7 +1046,7 @@ void MainDialog::OnFocusOut( wxFocusEvent& event )//////
 void MainDialog::OnAltMin( wxFocusEvent& event )//////altitude minute
 {
 	wxString str = m_textCtrl244->GetValue();
-	wxChar ch =',';
+	//wxChar ch =',';
 	double val,rest;
 	val = 0;
 	rest = 0;
@@ -1251,7 +1252,7 @@ void MainDialog::CalcMeridian()
 		strlat = signlat + strlat;
 		m_textCtrl2422->SetValue(strlat);
 	}
-	if(azimuth > 359 && azimuth < 360 || azimuth > 0 && azimuth < 1)
+	if((azimuth > 359 && azimuth < 360) || (azimuth > 0 && azimuth < 1))
 	{
 		if(dTrueAlt <= latitude)
 		{
@@ -1275,14 +1276,14 @@ void MainDialog::CalcMeridian()
 		m_textCtrl2422->SetValue(strlat);
 
 	}
-	else if(azimuth > 1 && azimuth < 179 || azimuth > 181 && azimuth < 359)
+	else if((azimuth > 1 && azimuth < 179) || (azimuth > 181 && azimuth < 359))
 		wxMessageBox(_("No meridian passage"),_("Error"));
 	
 }
 
 void MainDialog::OnCharHook(wxKeyEvent& event)
 {
-	wxWindow * ctrlWin;
+	//wxWindow * ctrlWin;
 	wxWindow *win = FindFocus ();
 	if (win == NULL)
 		{
@@ -1714,6 +1715,22 @@ void MainDialog::OnMenuAbout(wxCommandEvent& event)
 	AboutDialog dlg(this);
 	dlg.ShowModal();
 }
+
+void MainDialog::OnPlot(wxCommandEvent& event)
+{
+	GetData();
+	Plot_dialog dlg(this);
+	dlg.dDay = iDay;
+	dlg.dHour = iHour;
+	dlg.dMinute = iMinute;
+	dlg.dSeconds = iSeconds;
+	dlg.dYear = iYear;
+	dlg.dMonth = iMonth;
+	dlg.latitud = latitude;
+	dlg.longitud = longitude;
+	dlg.ShowModal();
+
+}
 /////////////////////////////////FUNZIONI DI CHIUSURA///////////ATAG/////////////////////////
 MainDialog::~MainDialog()
 {
@@ -1743,3 +1760,4 @@ void MainDialog::OnCloseDialog(wxCloseEvent& event)
 }
 
 
+
